# Pacifica Dispatcher
[![Build Status](https://travis-ci.org/pacifica/pacifica-dispatcher.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-dispatcher)
[![Build status](https://ci.appveyor.com/api/projects/status/vjcs904285d1jexn?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-dispatcher)
[![Maintainability](https://api.codeclimate.com/v1/badges/b75312dc89c170cb4510/maintainability)](https://codeclimate.com/github/pacifica/pacifica-dispatcher/maintainability)

[![Frontend Stars](https://img.shields.io/docker/stars/pacifica/dispatcher-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-frontend/general)
[![Backend Stars](https://img.shields.io/docker/stars/pacifica/dispatcher-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-backend/general)
[![Frontend Pulls](https://img.shields.io/docker/pulls/pacifica/dispatcher-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-frontend/general)
[![Backend Pulls](https://img.shields.io/docker/pulls/pacifica/dispatcher-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-backend/general)
[![Frontend Automated build](https://img.shields.io/docker/automated/pacifica/dispatcher-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-frontend/builds)
[![Backend Automated build](https://img.shields.io/docker/automated/pacifica/dispatcher-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/dispatcher-backend/builds)

Pacifica Dispatcher receives and handles [CloudEvents](https://cloudevents.io/) notifications.

## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-dispatcher.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
